.. image:: https://drone.io/github.com/socek/baelfire/status.png

1. Baelfire
===========
Baelfire is a yet another make-like program. Main goals for Baelfire is separete
implementation into 2 phase: recipe and task. Recipe have configuration and gather
tasks. Task have it's dependency, linked tasks (check before run this task) and
some other features. Recipe should be reusable. All is implemented in python.

2. Examples
===========
Baelfire is only a framework. For now there is only one ready to use command line
tool, please use `bael.project <https://github.com/socek/bael.project>`_

3. Documentation
================
Documentation is being made.
